"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const lodash_1 = require("lodash");
const mr_templates_1 = require("@cirrusct/mr-templates");
const templates_1 = require("@cirrusct/templates");
exports.getDashedName = (name) => {
    return lodash_1.camelCase(name)
        .replace(/([a-zA-Z])(?=[A-Z])/g, '$1-')
        .toLowerCase();
};
class DeployTemplateContext extends mr_templates_1.PackageTemplateContext {
    constructor(resolvedConfig, dependsOnServerContexts) {
        super(resolvedConfig.mrPackage, resolvedConfig.buildSpec, resolvedConfig.options, resolvedConfig.output, resolvedConfig.templateSourceFiles);
        this.resolvedConfig = resolvedConfig;
        // tslint:disable-next-line no-any
        this.getResolvedConfig = (path, defaultValue) => {
            return lodash_1.get(this.resolvedConfig, path, defaultValue);
        };
        this._dependsOnServerContexts = dependsOnServerContexts;
    }
    get startCmds() {
        const startCmds = this.getResolvedConfig('startCmds', []);
        return lodash_1.isArray(startCmds) ? startCmds : [startCmds];
    }
    get currentServerContext() {
        return this._currentServerContext;
    }
    set currentServerContext(server) {
        this._currentServerContext = server;
        this._deployModel = null;
    }
    get currentServerModel() {
        return this.currentServerContext ? this.currentServerContext.model : null;
    }
    get dependsOnServerModels() {
        return this.dependsOnServerContexts.map(serverContext => {
            return serverContext.model;
        });
    }
    set dependsOnServerContexts(contexts) {
        this._dependsOnServerContexts = contexts;
        this._deployModel = null;
    }
    get dependsOnServerContexts() {
        return this._dependsOnServerContexts || [];
    }
    get locations() {
        let locConfig = this.getResolvedConfig('locations', [{ url: '/' }]);
        if (lodash_1.isString(locConfig)) {
            locConfig = [
                {
                    url: locConfig,
                },
            ];
        }
        return locConfig;
    }
    get deploymentNameDashed() {
        return exports.getDashedName(this.resolvedConfig.name);
    }
    get model() {
        if (!this._deployModel) {
            this._deployModel = Object.assign({ deploymentName: this.resolvedConfig.name, deploymentNameDashed: this.deploymentNameDashed }, this.buildModel(), { dependsOnServers: this.dependsOnServerModels, startCmds: this.startCmds, currentServer: this.currentServerModel, port: this.getResolvedConfig('port'), volumes: this.getResolvedConfig('volumes') || [], mountPoints: this.getResolvedConfig('mountPoints') || [], portWs: this.getResolvedConfig('portWs'), locations: this.locations });
            this._deployModel.properties = templates_1.resolveModelTemplatePropertiesRecursive(this.resolvedConfig.properties, this._deployModel);
            this._deployModel = templates_1.resolveModelTemplatePropertiesToSelf(this._deployModel);
        }
        return this._deployModel;
    }
}
exports.DeployTemplateContext = DeployTemplateContext;
//# sourceMappingURL=DeployTemplateContext.js.map