"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const lodash_1 = require("lodash");
const core_node_1 = require("@cirrusct/core-node");
const mr_build_1 = require("@cirrusct/mr-build");
const DeployConfigResolver_1 = require("./DeployConfigResolver");
exports.getDeploymentConfigsMap = (monoRepo) => {
    const deployConfig = monoRepo.config.deploy;
    return deployConfig && deployConfig.deployments ? deployConfig.deployments : {};
};
exports.findPackagenames = (mrPackage) => {
    const mr = mrPackage.monoRepo;
    const deployConfig = mr.config.deploy;
    const found = [];
    if (deployConfig.deployments) {
        for (const name in deployConfig.deployments) {
            const config = deployConfig.deployments[name];
            let foundPkg = null;
            if (config.package) {
                // mrPackage is defined in deployment config.  Get the package using an acceptable form of it's name
                foundPkg = mr.findPackage(config.package);
            }
            else {
                // if mrPackage not defined, assuming key name matches a form of package name
                foundPkg = mr.findPackage(name);
            }
            if (foundPkg && foundPkg.name === mrPackage.name) {
                // add deployment to ret
                found.push(name);
            }
        }
    }
    return found;
};
exports.getPackagesWithDeployments = (monoRepo, filter = []) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    const packages = {};
    filter = filter.length > 0 ? filter : monoRepo.localPackages;
    for (const pkg of filter) {
        const names = exports.findPackagenames(pkg);
        if (names.length > 0) {
            packages[pkg.name] = pkg;
        }
    }
    return Object.keys(packages).map(pn => packages[pn]);
});
exports.getDeploymentConfigs = (pattern, mr) => {
    const deploymentConfigs = exports.getDeploymentConfigsMap(mr);
    const names = core_node_1.match(Object.getOwnPropertyNames(deploymentConfigs), pattern);
    const configs = {};
    for (const name of names) {
        configs[name] = deploymentConfigs[name];
    }
    return configs;
};
exports.matchnames = (pattern, mr) => {
    const deploymentConfigs = exports.getDeploymentConfigsMap(mr);
    return core_node_1.match(Object.getOwnPropertyNames(deploymentConfigs), pattern);
};
exports.getResolvedConfigs = (pattern, options = {}, mr, buildSpec) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    debugger;
    const configs = exports.getDeploymentConfigs(pattern, mr);
    const deployConfig = mr.config.deploy;
    let resolved = [];
    for (const deploymentConfigName in configs) {
        const deploymentConfig = configs[deploymentConfigName];
        const mrPackage = mr.findPackage(deploymentConfig.package);
        const buildConfig = yield mr_build_1.MrBuild.getPackageBuildConfig(mrPackage);
        // TODO: hack, centralize this
        buildSpec =
            buildSpec || lodash_1.get(buildConfig.specs, 'default', lodash_1.get(buildConfig.specs, Object.keys(buildConfig.specs)[0]));
        const resolver = new DeployConfigResolver_1.DeploymentConfigResolver(mrPackage, deployConfig, buildSpec, options, deploymentConfigName);
        resolved.push(...(yield resolver.resolve()));
    }
    return resolved;
});
//# sourceMappingURL=config.js.map