"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_node_1 = require("@cirrusct/core-node");
const shellExec_1 = require("./shellExec");
const deploy_1 = require("../deploy");
exports.commandHandler = (args) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    const { options = {}, logger, packages } = args;
    if (!options.deployment) {
        logger.warn('Docker: No Deployment specified.');
        return Promise.resolve();
    }
    try {
        const resolvedConfigs = yield deploy_1.getResolvedConfigs(options.deployment, { dotEnvPath: options.dotEnvPath }, args.monoRepo);
        if (resolvedConfigs.length === 0) {
            logger.warn(`Docker: No Deployment matching '${options.deployment}'`);
            return Promise.resolve();
        }
        else if (resolvedConfigs.length > 1) {
            logger.warn(`Docker: Pattern '${options.deployment}' resolves to more than 1 config.  Please specify a single deployment.`);
            return Promise.resolve();
        }
        const resolvedConfig = resolvedConfigs[0];
        yield shellExec_1.shellDocker(resolvedConfig, options, args.monoRepo, logger);
        logger.info(`Docker on ${resolvedConfig.name} in path ${resolvedConfig.output}`);
    }
    catch (e) {
        throw core_node_1.createError(`Deploy Command Failed`, e);
    }
});
//# sourceMappingURL=handler.js.map