"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path = require("path");
const core_node_1 = require("@cirrusct/core-node");
exports.shellDocker = (config, options, mr, logger) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    try {
        if (!(options.composeBuild || options.composeUp)) {
            logger.warn(`No operation specified.  Expected either 'build' or 'up'`);
            process.exit(1);
        }
        const operation = options.composeUp ? `up${options.composeBuild ? ' --build' : ''}` : 'build';
        const composeFilePath = path.join(config.output, 'docker-compose.yml');
        if (!composeFilePath) {
            throw core_node_1.createError(`docker-compose.yml not found at ${composeFilePath}`);
        }
        // this only works for docker-compose 'run'.  Need to sort out how to handle env in general
        let envCli = null;
        // if (options.dotEnvPath) {
        //     envCli = envVarsToDockerCli(mr.getEnv(options.dotEnvPath));
        // }
        const cmdLine = `docker-compose -f "${path.relative(process.cwd(), composeFilePath)}"${envCli ? ` ${envCli}` : ''} ${operation}`;
        //console.log(cmdLine);
        logger.info({ cmdLine }, 'Shelling to docker-compose');
        const result = yield core_node_1.shellExec(cmdLine, { ignoreErrorCode: true });
    }
    catch (err) {
        logger.error({}, err.message);
        throw core_node_1.createError('shellDocker Failed', err);
    }
});
//# sourceMappingURL=shellExec.js.map