import { MrCliCommandGlobalOptions, MrCliCommandDefinition } from '@cirrusct/mr-command';
import { MrDeployOptions } from './types';

export interface DeployFlags extends MrCliCommandGlobalOptions {
    generate?: boolean;
    showConfig?: boolean;
    output?: string;
    env?: string;
    deployment?: string;
}

export const deploy: MrCliCommandDefinition<DeployFlags, MrDeployOptions> = {
    name: 'deploy',
    description: 'Deploy',
    transformOptions: options => {
        return {
            ...options,
            dotEnvPath: options.env,
        }
    },
    options: [
        {
            name: 'generate',
            flag: 'g',
            valueType: 'boolean',
            description: 'Generate Deploy files',
        },
        {
            name: 'showConfig',
            flag: 'c',
            valueType: 'boolean',
            description: 'Show resolved config',
        },
        {
            name: 'output',
            flag: 'o',
            valueType: 'string',
            description: 'Output File Name (for generator)',
        },
        {
            name: 'env',
            flag: 'e',
            valueType: 'string',
            description: 'File containing Environment variables (.env syntax)',
        },
        {
            name: 'deployment',
            valueType: 'string',
            description: 'Name or Pattern for Deployment to operate on',
        },
    ],
};
