import { MrCliCommandGlobalOptions, MrCliCommandDefinition } from '@cirrusct/mr-command';
import { MrDockerOptions } from './types';

export interface DockerCliOptions extends MrCliCommandGlobalOptions {
    env?: string;
    deployment?: string;
    up?: boolean;
    run?: boolean;
    build?: boolean;
    tag?: string;
}

export const docker: MrCliCommandDefinition<DockerCliOptions, MrDockerOptions> = {
    name: 'docker',
    description: 'Docker',
    transformOptions: options => {
        return {
            ...options,
            dotEnvPath: options.env,
            composeUp: options.run || options.up || false,
            composeBuild: options.build || false,
        }
    },
    options: [
        {
            name: 'env',
            flag: 'e',
            valueType: 'string',
            description: 'File containing Environment variables (.env syntax)',
        },
        {
            name: 'deployment',
            valueType: 'string',
            description: 'Name or Pattern for Deployment to operate on',
        },
        {
            name: 'run',
            flag: 'r',
            valueType: 'boolean',
            description: 'docker-compose.yml up for defined for template',
        },
        {
            name: 'up',
            valueType: 'boolean',
            description: 'docker-compose.yml up for defined for template',
        },
        {
            name: 'build',
            flag: 'b',
            valueType: 'boolean',
            description: 'Build docker-compose.yml defined for template',
        },
        {
            name: 'tag',
            flag: 't',
            valueType: 'boolean',
            description: 'Tag for image',
        },
    ],
};
